@@ -1,11 +1,13 @@
 package segments
 
 import (
+	"fmt"
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
 )
@@ -20,6 +22,8 @@ func TestSessionSegmentTemplate(t *testing.T) {
 		SSHSession      bool
 		Root            bool
 		Template        string
+		WhoAmI          string
+		Platform        string
 	}{
 		{
 			Case:           "user and computer",
@@ -87,10 +91,29 @@ func TestSessionSegmentTemplate(t *testing.T) {
 			Root:            true,
 			Template:        "{{if ne .Env.POSH_SESSION_DEFAULT_USER .UserName}}{{.UserName}}{{end}}",
 		},
+		{
+			Case:           "user with ssh using who am i",
+			ExpectedString: "john on remote",
+			UserName:       "john",
+			SSHSession:     false,
+			WhoAmI:         "sascha   pts/1        2023-11-08 22:56 (89.246.1.1)",
+			ComputerName:   "remote",
+			Template:       "{{.UserName}}{{if .SSHSession}} on {{.HostName}}{{end}}",
+		},
+		{
+			Case:           "user with ssh using who am i (windows)",
+			ExpectedString: "john",
+			UserName:       "john",
+			SSHSession:     false,
+			WhoAmI:         "sascha   pts/1        2023-11-08 22:56 (89.246.1.1)",
+			Platform:       runtime.WINDOWS,
+			ComputerName:   "remote",
+			Template:       "{{.UserName}}{{if .SSHSession}} on {{.HostName}}{{end}}",
+		},
 	}
 
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		env.On("User").Return(tc.UserName)
 		env.On("GOOS").Return("burp")
 		env.On("Host").Return(tc.ComputerName, nil)
@@ -100,7 +123,7 @@ func TestSessionSegmentTemplate(t *testing.T) {
 		}
 		env.On("Getenv", "SSH_CONNECTION").Return(SSHSession)
 		env.On("Getenv", "SSH_CLIENT").Return(SSHSession)
-		env.On("TemplateCache").Return(&platform.TemplateCache{
+		env.On("TemplateCache").Return(&cache.Template{
 			UserName: tc.UserName,
 			HostName: tc.ComputerName,
 			Env: map[string]string{
@@ -110,6 +133,16 @@ func TestSessionSegmentTemplate(t *testing.T) {
 			},
 			Root: tc.Root,
 		})
+
+		env.On("Platform").Return(tc.Platform)
+
+		var whoAmIErr error
+		if len(tc.WhoAmI) == 0 {
+			whoAmIErr = fmt.Errorf("who am i error")
+		}
+
+		env.On("RunCommand", "who", []string{"am", "i"}).Return(tc.WhoAmI, whoAmIErr)
+
 		session := &Session{
 			env:   env,
 			props: properties.Map{},
