@@ -1,8 +1,8 @@
 package segments
 
 import (
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Swift struct {
@@ -13,11 +13,11 @@ func (s *Swift) Template() string {
 	return languageTemplate
 }
 
-func (s *Swift) Init(props properties.Properties, env platform.Environment) {
+func (s *Swift) Init(props properties.Properties, env runtime.Environment) {
 	s.language = language{
 		env:        env,
 		props:      props,
-		extensions: []string{"*.swift", "*.SWIFT"},
+		extensions: []string{"*.swift", "*.SWIFT", "Podfile"},
 		commands: []*cmd{
 			{
 				executable: "swift",
